@@ -214,11 +214,7 @@ class BaseTest(unittest.TestCase):
         app.button("Continue").click()
 
     def get_file_chooser(self, name):
-        if os.environ["DD_MODE"] == "snap":
-            # snap uses native dialog with an old gtk
-            dlg = Gtk4Node(tree.root).child(roleName="dialog", name=name)
-        else:
-            dlg = Gtk4Node(tree.root).child(roleName="filler", name=name)
+        dlg = Gtk4Node(tree.root).child(roleName="dialog", name=name)
 
         # Focus dialog (not always done automatically with portal dialogs)
         dlg.child(roleName="panel").click()
@@ -226,8 +222,9 @@ class BaseTest(unittest.TestCase):
         return dlg
 
     def click_restore_button(self, parent):
-        bar = parent.child(name="Actions")
-        bar.button("Restore").click()
+        buttons = parent.findChildren(GenericPredicate(roleName="push button", name="Restore"))
+        self.assertEqual(len(buttons), 2)  # first is top tab, second is bottom button
+        buttons[1].click()
 
     def get_config(self, section, option, fallback=None, required=True):
         if not self.config:
